==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/funzioni.php <==
<?php

switch ($messaggio) {

case "<div style=\"display: inline; color: red;\">ERRORE</div> di scrittura del file":  		$messaggio = "<div style=\"display: inline; color: red;\">FEL</div> vid skrivning till fil"; break;
case "Nome utente":  				$messaggio = "Anv&auml;ndarnamn"; break;
case "Password":  				$messaggio = "L&ouml;senord"; break;
case "Entra":  					$messaggio = "Inloggning"; break;
case "Sessione <div style=\"display: inline; color: red;\">scaduta</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Utg&aring;ngen</div> session"; break;
case "Nome utente o password <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Felaktigt</div> anv&auml;ndarnamn eller l&ouml;senord"; break;
case "Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi":	$messaggio = "F&ouml;r m&aring;nga <div style=\"display: inline; color: red;\">felaktiga</div> inloggningsf&ouml;rs&ouml;k dom senaste"; break;
case "minuti":  				$messaggio = "minuterna"; break;
case "Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere":	$messaggio = "Efter ett <div style=\"display: inline; color: red;\">felaktigt</div> inloggningsf&ouml;rs&ouml;k m&aring;ste du v&auml;nta"; break;
case "secondi":  				$messaggio = "sekunder"; break;
case "Il database deve essere aggiornato":  	$messaggio = "Databasen m&aring;ste uppdateras"; break;
case "Aggiorna":  				$messaggio = "Uppdatera"; break;
case "Login per HotelDruid":  			$messaggio = "Login for HotelDruid"; break;
case "Mancano solo":  				$messaggio = "Only"; break;
case "tentativi prima del blocco dei login": 	$messaggio = "attempts remaining before locking the login"; break;
case "Manca solo":  				$messaggio = "Only"; break;
case "tentativo prima del blocco dei login":	$messaggio = "attempt remaining before locking the login"; break;
case "È possibile reimpostare la password dal proprio account di hosting":	$messaggio = "You can reset the password from your hosting account"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_3.0.3-1.tar.gz: sv/funzioni.php <==
<?php

switch ($messaggio) {

case "<div style=\"display: inline; color: red;\">ERRORE</div> di scrittura del file":  		$messaggio = "<div style=\"display: inline; color: red;\">FEL</div> vid skrivning till fil"; break;
case "Nome utente":  				$messaggio = "Anv&auml;ndarnamn"; break;
case "Password":  				$messaggio = "L&ouml;senord"; break;
case "Entra":  					$messaggio = "Inloggning"; break;
case "Sessione <div style=\"display: inline; color: red;\">scaduta</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Utg&aring;ngen</div> session"; break;
case "Nome utente o password <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Felaktigt</div> anv&auml;ndarnamn eller l&ouml;senord"; break;
case "Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi":	$messaggio = "F&ouml;r m&aring;nga <div style=\"display: inline; color: red;\">felaktiga</div> inloggningsf&ouml;rs&ouml;k dom senaste"; break;
case "minuti":  				$messaggio = "minuterna"; break;
case "Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere":	$messaggio = "Efter ett <div style=\"display: inline; color: red;\">felaktigt</div> inloggningsf&ouml;rs&ouml;k m&aring;ste du v&auml;nta"; break;
case "secondi":  				$messaggio = "sekunder"; break;
case "Il database deve essere aggiornato":  	$messaggio = "Databasen m&aring;ste uppdateras"; break;
case "Aggiorna":  				$messaggio = "Uppdatera"; break;
case "Login per HotelDruid":  			$messaggio = "Login for HotelDruid"; break;
case "Mancano solo":  				$messaggio = "Only"; break;
case "tentativi prima del blocco dei login": 	$messaggio = "attempts remaining before locking the login"; break;
case "Manca solo":  				$messaggio = "Only"; break;
case "tentativo prima del blocco dei login":	$messaggio = "attempt remaining before locking the login"; break;
case "È possibile reimpostare la password dal proprio account di hosting":	$messaggio = "You can reset the password from your hosting account"; break;
case "orario del server":  			$messaggio = "server time"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "Mancano meno di":  			$messaggio = "Less than"; break;
case "giorni alla scadenza dell'account":  	$messaggio = "days left until the account expires"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
